#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVFLOOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVFLOOR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/divfloor.hpp>

#endif
